@@ -1,4 +1,4 @@
-/* Copyright 2015 the unarr project authors (see AUTHORS file).
+/* Copyright 2018 the unarr project authors (see AUTHORS file).
    License: LGPLv3 */
 
 #ifndef _7z_7z_h
@@ -8,7 +8,7 @@
 
 #include "../lzmasdk/7zTypes.h"
 #ifdef HAVE_7Z
-#include <7z.h>
+#include "../lzmasdk/7z.h"
 #endif
 
 typedef struct ar_archive_7z_s ar_archive_7z;
@@ -33,11 +33,15 @@ struct ar_archive_7z_s {
     ar_archive super;
     struct CSeekStream in_stream;
 #ifdef HAVE_7Z
-    CLookToRead look_stream;
+    CLookToRead2 look_stream;
     CSzArEx data;
 #endif
     char *entry_name;
     struct ar_archive_7z_uncomp uncomp;
 };
 
+#ifndef USE_7Z_CRC32
+UInt32 Z7_FASTCALL CrcCalc(const void *data, size_t size);
+#endif
+
 #endif
