@@ -50,10 +50,13 @@ bool RARProgramAddInstr(RARProgram *prog, uint8_t instruction, bool bytemode)
         /* in my small file sample, 16 is the value needed most often */
         uint32_t newCapacity = prog->capacity ? prog->capacity * 4 : 32;
         RAROpcode *newCodes = calloc(newCapacity, sizeof(*prog->opcodes));
-        if (!newCodes)
+        if (!newCodes) {
             return false;
-        memcpy(newCodes, prog->opcodes, prog->capacity * sizeof(*prog->opcodes));
-        free(prog->opcodes);
+        }
+        if (prog->opcodes) {
+            memcpy(newCodes, prog->opcodes, prog->capacity * sizeof(*prog->opcodes));
+            free(prog->opcodes);
+        }
         prog->opcodes = newCodes;
         prog->capacity = newCapacity;
     }
