@@ -32,7 +32,7 @@ struct tar_entry {
 bool tar_parse_header(ar_archive_tar *tar);
 bool tar_handle_pax_extended(ar_archive *ar);
 bool tar_handle_gnu_longname(ar_archive *ar);
-const char *tar_get_name(ar_archive *ar);
+const char *tar_get_name(ar_archive *ar, bool raw);
 
 /***** tar *****/
 
