@@ -177,7 +177,11 @@ static bool zip_init_uncompress_lzma(struct ar_archive_zip_uncomp *uncomp)
 {
     lzma_stream strm = LZMA_STREAM_INIT;
     uncomp->state.lzmastream = strm;
-    static const lzma_allocator allocator = { gLzma_Alloc, gLzma_Free, NULL };
+    #if LZMA_VERSION_MAJOR > 5 || (LZMA_VERSION_MAJOR == 5 && LZMA_VERSION_MINOR >= 2)
+      static const lzma_allocator allocator = { gLzma_Alloc, gLzma_Free, NULL };
+    #else
+      static lzma_allocator allocator = { gLzma_Alloc, gLzma_Free, NULL };
+    #endif
     uncomp->state.lzmastream.allocator = &allocator;
     return true;
 }
@@ -396,7 +400,7 @@ static uint32_t zip_uncompress_data_ppmd(struct ar_archive_zip_uncomp *uncomp, v
 #endif
         if (!Ppmd8_Alloc(&uncomp->state.ppmd8.ctx, (size + 1) << 20, &uncomp->state.ppmd8.alloc))
             return ERR_UNCOMP;
-        if (!Ppmd8_RangeDec_Init(&uncomp->state.ppmd8.ctx))
+        if (!Ppmd8_Init_RangeDec(&uncomp->state.ppmd8.ctx))
             return ERR_UNCOMP;
         Ppmd8_Init(&uncomp->state.ppmd8.ctx, order, method);
     }
